Debugging - kombu.utils.debug — Kombu v1.3.2 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »

# Debugging - kombu.utils.debug

class `kombu.utils.debug.` `Logwrapped`(instance, logger=None, ident=None)

`kombu.utils.debug.` `setup_logging`(loglevel=10, loggers=['kombu.connection', 'kombu.channel'])

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »